#ifndef __Marzani_coeffs__
#define __Marzani_coeffs__

#include <fstream>
#include <vector>
#include <gsl/gsl_interp.h>
#include <gsl/gsl_spline.h>
#include "finite-mt_small-x_coeffs.hh"
#include <string>
//using namespace std;



const double mtop0 = 172.5;


SmallxCoeffs::SmallxCoeffs(std::string filename) {
  init_smallx_mt(filename);
}


double SmallxCoeffs::c1marzani(double mH, double mtop) {
  gsl_interp_accel *acc = gsl_interp_accel_alloc ();
  gsl_spline *spline = gsl_spline_alloc (gsl_interp_cspline, mN);
  gsl_spline_init (spline, mmh, mc1, mN);
  double val = gsl_spline_eval (spline, mH*(mtop0/mtop), acc);
  gsl_spline_free (spline);
  gsl_interp_accel_free (acc);
  return val;
}
double SmallxCoeffs::c2marzani(double mH, double mtop) {
  gsl_interp_accel *acc = gsl_interp_accel_alloc ();
  gsl_spline *spline = gsl_spline_alloc (gsl_interp_cspline, mN);
  gsl_spline_init (spline, mmh, mc2, mN);
  double val = gsl_spline_eval (spline, mH*(mtop0/mtop), acc);
  gsl_spline_free (spline);
  gsl_interp_accel_free (acc);
  return val;
}
double SmallxCoeffs::c3marzani(double mH, double mtop) {
  gsl_interp_accel *acc = gsl_interp_accel_alloc ();
  gsl_spline *spline = gsl_spline_alloc (gsl_interp_cspline, mN);
  gsl_spline_init (spline, mmh, mc3, mN);
  double val = gsl_spline_eval (spline, mH*(mtop0/mtop), acc);
  gsl_spline_free (spline);
  gsl_interp_accel_free (acc);
  return val;
}




void SmallxCoeffs::init_smallx_mt(std::string filename) {
  if(filename == "") filename = "MBDFV.dat";
  std::ifstream infile(filename.c_str());
  std::vector<double> mH, c1, c2, c3;
  double d1, d2, d3, d4;
  do {
    infile >> d1 >> d2 >> d3 >> d4;
    mH.push_back(d1);
    c1.push_back(d2);
    c2.push_back(d3);
    c3.push_back(d4);
  } while(infile.good());
  mH.pop_back();
  c1.pop_back();
  c2.pop_back();
  c3.pop_back();
  //
  mN = mH.size();
  if(mmh != NULL) delete mmh;
  if(mc1 != NULL) delete mc1;
  if(mc2 != NULL) delete mc2;
  if(mc3 != NULL) delete mc3;
  mmh = new double[mN];
  mc1 = new double[mN];
  mc2 = new double[mN];
  mc3 = new double[mN];
  for(int i=0; i<mN; i++) {
    mmh[i] = mH[i];
    mc1[i] = c1[i];
    mc2[i] = c2[i];
    mc3[i] = c3[i];
  }
  infile.close();
}


#endif
